import {Component, OnDestroy, OnInit} from '@angular/core';
import {StudentViewService} from 'src/app/services/student-view.service';
import {StudentInfoService} from 'src/app/services/student-info.service';
import {StudentDataService} from 'src/app/services/student-data.service';
import {QuestionDao} from 'src/app/dao/question.dao';
import {AnswerDao} from 'src/app/dao/answer.dao';
import {MinutePaperDao} from 'src/app/dao/minute-paper.dao';
import {FormArray, FormBuilder, FormGroup} from '@angular/forms';
import {StudentResponseDao} from 'src/app/dao/student-response.dao';

@Component({
    selector: 'app-student-submission-view',
    templateUrl: './student-submission-view.component.html',
    styleUrls: ['./student-submission-view.component.css']
})
export class StudentSubmissionViewComponent implements OnInit, OnDestroy {

  private studentResponse: StudentResponseDao[];
  public submissionForm: FormGroup;
  public currentPaper: MinutePaperDao;
  public studentId: String;
  public answerList: AnswerDao[];
  public questionList: QuestionDao[];

  constructor(private studentViewService: StudentViewService,
              private studentInfoService: StudentInfoService,
              private studentDataService: StudentDataService,
              private formBuilder: FormBuilder) {
  }

  ngOnInit(): void {
    this.submissionForm = this.formBuilder.group({
      questions: this.formBuilder.array([])
    });
    this.currentPaper = this.studentDataService.currentPaper;
    this.studentId = this.studentDataService.studentId;
    this.questionList = [];
    this.answerList = [];
    this.studentResponse = [];
    this.getQuestions();
    this.getAnswers();
  }

  ngOnDestroy(): void {
    this.questionList = [];
    this.answerList = [];
    this.studentResponse = [];
  }

  public submit(): void {
    this.populateAnswers();
    this.studentInfoService.submitResponse(this.studentResponse).subscribe();
  }

  public save(): void {
    this.populateAnswers();
    this.studentInfoService.saveDraft(this.studentResponse).subscribe();
  }

  private populateAnswers(): void {
    let index = 0;
    this.questionList.forEach(q => {
      if (this.submissionForm.get('questions').get(index.toString()) !== null) {
        this.studentResponse.push(new StudentResponseDao(this.studentId, this.currentPaper.paperId,
          q.questionId, this.submissionForm.get('questions').get(index.toString()).value));
        index++;
      }
    });
  }

  private getFormQuestions(): FormArray {
    return this.submissionForm.get('questions') as FormArray;
  }

  private organise(): void {
    for (let i = 0; i < this.questionList.length; i++) {
      if (this.questionList[i] && this.answerList[i]) {
        this.getFormQuestions().push(this.formBuilder.control(this.answerList[i].answerText));
      } else {
        this.getFormQuestions().push(this.formBuilder.control(''));
      }
    }
  }

  private getQuestions(): void {
    this.studentInfoService.getPaperQuestions(this.studentId, this.currentPaper.paperId).subscribe((data: QuestionDao[]) => {
      data.forEach(e => this.questionList.push(e));
      this.organise();
    });
  }

  private getAnswers(): void {
    this.studentInfoService.getStudentAnswers(this.studentId, this.currentPaper.paperId).subscribe((data: AnswerDao[]) => {
      data.forEach(e => this.answerList.push(e));
      this.organise();
    });
  }

}
